@@ -1,10 +1,10 @@
 /* Pathname hacking.
-   Copyright (C) 2001-2002 Free Software Foundation, Inc.
+   Copyright (C) 2001-2002, 2007, 2010 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2001.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -23,7 +23,8 @@
 #include <string.h>
 
 #ifndef PARAMS
-# if __STDC__ || defined __GNUC__ || defined __SUNPRO_C || defined __cplusplus || __PROTOTYPES
+# if __STDC__ || defined __GNUC__ || defined __SUNPRO_C || \
+     defined __cplusplus || __PROTOTYPES
 #  define PARAMS(args) args
 # else
 #  define PARAMS(args) ()
@@ -33,8 +34,10 @@
 #if !(__GLIBC__ >= 2)
 /* When not using the GNU libc we use the basename implementation we
    provide here.  */
-extern char *gnu_basename PARAMS ((const char *));
-#define basename(Arg) gnu_basename (Arg)
+
+extern char *base_name PARAMS ((const char *));
+#define basename(Arg) base_name (Arg)
+
 #endif
 
 #endif /* _BASENAME_H */
